// Copyright 2019 Sorint.lab
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied
// See the License for the specific language governing permissions and
// limitations under the License.

package executor

import (
	"encoding/base64"
	"encoding/json"

	"github.com/sorintlab/agola/internal/services/runservice/types"

	dtypes "github.com/docker/docker/api/types"
	"github.com/pkg/errors"
)

func registryAuthToken(auth *types.RegistryAuth) (string, error) {
	if auth == nil {
		return "", nil
	}

	switch auth.Type {
	case types.RegistryAuthTypeDefault:
		authConfig := dtypes.AuthConfig{
			Username: auth.Username,
			Password: auth.Password,
		}
		authConfigj, err := json.Marshal(authConfig)
		if err != nil {
			panic(err)
		}
		return base64.URLEncoding.EncodeToString(authConfigj), nil

	default:
		return "", errors.Errorf("unsupported registry auth type %q", auth.Type)
	}
}
